/**
 * The opposite of `@lavadrop/pick`; this method creates an object composed of the
 * object's own properties that are not in the list of omitted keys.
 * @param object The source object.
 * @param keys The object keys to omit.
 * @category Object
 * @returns A new object with specified keys omitted.
 * @example
const obj = { a: 1, b: 2, c: 3 }

omit(obj, 'a', 'c')
// => { b: 2 }
 */
export default function omit(object, ...keys) {
	return Object.keys(object).reduce((result, key) => {
		if (!keys.includes(key)) {
			result[key] = object[key]
		}
		return result
	}, {})
}
